@@ -33,6 +33,26 @@ test_that("recipes", {
   rec_4 <- recipes::recipe(mpg ~ ., data = mtcars) %>% recipes::step_rm(mpg)
   expect_equal(outcome_names(rec_4), "mpg")
   expect_equal(outcome_names(recipes::prep(rec_4)), character(0))
+
+  rec_5 <- recipes::recipe(mtcars)
+  expect_equal(outcome_names(rec_5), character())
+  expect_equal(outcome_names(recipes::prep(rec_5)), character(0))
+
+  rec_6 <- recipes::recipe(mtcars) %>%
+    recipes::update_role(mpg, new_role = "outcome")
+  expect_equal(outcome_names(rec_6), "mpg")
+  expect_equal(outcome_names(recipes::prep(rec_6)), "mpg")
+
+  rec_7 <- recipes::recipe(mtcars) %>%
+    recipes::update_role(mpg, disp, new_role = "outcome")
+  expect_equal(outcome_names(rec_7), c("mpg", "disp"))
+  expect_equal(outcome_names(recipes::prep(rec_7)), c("mpg", "disp"))
+
+  rec_8 <- recipes::recipe(mtcars) %>%
+    recipes::update_role(mpg, disp, new_role = "outcome") %>%
+    recipes::step_rm(mpg)
+  expect_equal(outcome_names(rec_8), c("mpg", "disp"))
+  expect_equal(outcome_names(recipes::prep(rec_8)), "disp")
 })
 
 
@@ -41,6 +61,8 @@ test_that("recipes", {
 test_that("workflows + recipes", {
   rec_1 <- recipes::recipe(mpg ~ ., data = mtcars)
   rec_2 <- recipes::recipe(mpg + wt ~ ., data = mtcars)
+  rec_3 <- recipes::recipe(mtcars) %>%
+    recipes::update_role(mpg, new_role = "outcome")
   lm_mod <- parsnip::linear_reg() %>% parsnip::set_engine("lm")
   wflow <- workflow() %>% add_model(lm_mod)
 
@@ -51,6 +73,10 @@ test_that("workflows + recipes", {
   wflow_2 <- wflow %>% add_recipe(rec_2)
   expect_equal(outcome_names(wflow_2), c("mpg", "wt"))
   expect_equal(outcome_names(parsnip::fit(wflow_2, mtcars)), c("mpg", "wt"))
+
+  wflow_3 <- wflow %>% add_recipe(rec_3)
+  expect_equal(outcome_names(wflow_3), "mpg")
+  expect_equal(outcome_names(parsnip::fit(wflow_3, mtcars)), "mpg")
 })
 
 
